@@ -14,7 +14,7 @@ package MCE::Core::Manager;
 use strict;
 use warnings;
 
-our $VERSION = '1.833';
+our $VERSION = '1.836';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
@@ -116,7 +116,7 @@ sub _output_loop {
       my $_ret = $_cb->(@_);
 
       return print {$_DAU_R_SOCK} length($_ret).'0'.$LF, $_ret
-         if ( !ref $_ret && defined $_ret && !looks_like_number $_ret );
+         if ( !looks_like_number $_ret && !ref $_ret && defined $_ret );
 
       my $_buf = $self->{freeze}([ $_ret ]);
 
@@ -570,8 +570,6 @@ sub _output_loop {
          read $_DAU_R_SOCK, $_buf, $_len;
 
          unless (exists $_sendto_fhs{$_fd}) {
-            require IO::Handle unless $INC{'IO/Handle.pm'};
-
             $_sendto_fhs{$_fd} = IO::Handle->new();
             $_sendto_fhs{$_fd}->fdopen($_fd, 'w')
                or _croak "Cannot open file descriptor ($_fd): $!";
